@@ -2,17 +2,17 @@
 This module contains the base objects of the JSON structure
 """
 import json
-import sys
+import os
 from datetime import date, datetime, time
 from pathlib import Path
-from typing import Union
+from typing import List, Union
 from uuid import uuid4
 
+import pyperclip
 import requests
 from bs4 import BeautifulSoup
 
 import jsonutils.config as config
-from jsonutils.cache import memoized_method
 from jsonutils.encoders import JSONObjectEncoder
 from jsonutils.exceptions import (
     JSONDecodeException,
@@ -20,12 +20,7 @@ from jsonutils.exceptions import (
     JSONQueryException,
     JSONQueryMultipleValues,
 )
-from jsonutils.functions.decorators import (
-    catch_exceptions,
-    dummy,
-    global_config,
-    return_value_on_exception,
-)
+from jsonutils.functions.decorators import dummy, global_config, return_value_on_exception
 from jsonutils.functions.external import (
     DjangoQuerySet,
     NumpyArray,
@@ -48,6 +43,7 @@ from jsonutils.functions.parsers import (
     parse_timestamp,
     url_validator,
 )
+from jsonutils.functions.reader import _open_multiple_files, _open_single_file
 from jsonutils.functions.seekers import (
     _eval_object,
     _json_from_path,
@@ -159,6 +155,7 @@ class JSONObject:
         "_id",
         "_child_objects",
         "_is_annotation",
+        "_storage_path",
     )
 
     def __new__(
@@ -214,28 +211,36 @@ class JSONObject:
                 raise JSONDecodeException(f"Wrong data's format: {type(data)}")
 
     @classmethod
-    def open(cls, file: str, raise_exception: bool = True, **kwargs):
+    def open(cls, file: Union[str, List[str]], raise_exception: bool = True, **kwargs):
         """
-        Open an external JSON file.
-        If a valid url string is passed, then it will try to make a get/post request to such a target and decode a json file
+        Open an external/s JSON file/s.
+
+        Params
+        ------
+        - `file`: str or list of str. Specifies the file/s you want to open.
+        If a valid url string is passed, then it will try to make a get/post request to such a target and decode a json file.
+        If a list is passed, then it will load multiple JSONObjects.
+        - `raise_exception`: If True, an exception will be thrown if the request is not successfull after 10 tries.
         """
-        # decide whether to use requests.get or requests.post by checking kwargs
-        if kwargs.get("json") or kwargs.get("data"):
-            FUNCTION = requests.post
+
+        if isinstance(file, (str, os.PathLike)):
+            data, _ = _open_single_file(file, raise_exception, **kwargs)
+            return cls(data)
+        elif isinstance(file, (tuple, list)):
+            data = _open_multiple_files(file, raise_exception, **kwargs)
+            output = JSONResults()
+            for elem in data:
+                obj = elem[0]
+                path = elem[1]
+                obj = cls(obj)
+                obj._storage_path = path
+                output.append(obj)
+            return output
+
         else:
-            FUNCTION = requests.get
-        file = str(file)
-        if url_validator(file):
-            req = retry_function(FUNCTION, file, raise_exception=raise_exception, **kwargs)
-            try:
-                data = req.json()
-            except Exception as e:
-                raise JSONDecodeException(f"Selected URL has no valid json file. Details: {e}")
-            else:
-                return cls(data)
-        with open(file) as f:
-            data = json.load(f)
-        return cls(data)
+            raise TypeError(
+                f"`file` argument can be only of type `str` or `list`, not {type(file)}"
+            )
 
     @classmethod
     def loads(cls, string, **kwargs):
@@ -250,6 +255,11 @@ class JSONObject:
         else:
             return cls(data)
 
+    @classmethod
+    def read_from_clipboard(cls):
+        clipboard_data = pyperclip.paste()
+        return cls.loads(clipboard_data)
+
     @staticmethod
     def read_html_table(
         data,
@@ -1884,3 +1894,8 @@ class JSONUnknown(JSONSingleton):
 
     def __le__(self, other):
         return False
+
+
+class JSONResults(list):
+    def save(self):
+        [obj.save(obj._storage_path) for obj in self]
